@@ -1,12 +1,12 @@
 # coding: utf-8
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 import typing
@@ -17,6 +17,7 @@ from groundx.configuration import Configuration
 from groundx.api_client import ApiClient
 from groundx.type_util import copy_signature
 from groundx.apis.tags.buckets_api import BucketsApi
+from groundx.apis.tags.customer_api import CustomerApi
 from groundx.apis.tags.documents_api import DocumentsApi
 from groundx.apis.tags.health_api import HealthApi
 from groundx.apis.tags.projects_api import ProjectsApi
@@ -34,6 +35,7 @@ class Groundx(ClientCustom):
             raise Exception("configuration is required")
         api_client = ApiClient(configuration)
         self.buckets: BucketsApi = BucketsApi(api_client)
+        self.customer: CustomerApi = CustomerApi(api_client)
         self.documents: DocumentsApi = DocumentsApi(api_client)
         self.health: HealthApi = HealthApi(api_client)
         self.projects: ProjectsApi = ProjectsApi(api_client)
